Crate inclusive

Crate inclusive 

Macros

bake
def_lang

Structs

FilePath
Include
Metadata
ModuleName

Traits

Compileable
A include that provides some mechanism to transform its content into another form using additional context (e.g. a std library or imports)
Data
An include that only contains text parse() will always succeed, simply returning the underlying data as a &'static str
Parseable
An include that provides some mechanism to verify the content of the included file
Runner
Something that can interpret an Include to produce a Value or Error at runtime